gchecky.model.merchant_calculations_t

Package gchecky :: Module model :: Class merchant_calculations_t |
[hide private]
[frames] | no frames]

# Class merchant_calculations_t

source code

    object --+
             |
     gxml.Node --+
                 |
                merchant_calculations_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| merchant_calculations_url = `Url:PATH(merchant-calculations-url`...``
| accept_merchant_coupons = `gxml.Boolean('accept-merchant-coupon`...``
| accept_gift_certificates = `gxml.Boolean('accept-gift-certifica`...``
| _fields = ``{``'``accept_gift_certificates``'``:` `??``,` `'``accept_merchant_coup``...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### merchant_calculations_url Value:
      Url:PATH(merchant-calculations-url):REQ:EMPTY

  ### accept_merchant_coupons Value:
      gxml.Boolean('accept-merchant-coupons', required= False)

  ### accept_gift_certificates Value:
      gxml.Boolean('accept-gift-certificates', required= False)

  ### _fields list of meta-Fields of this class. Value:
      {'accept_gift_certificates': ??,
       'accept_merchant_coupons': ??,
       'merchant_calculations_url': Url:PATH(merchant-calculations-url):REQ:
      EMPTY}